@@ -1,6 +1,6 @@
 package Silki::Schema::Wiki;
 BEGIN {
-  $Silki::Schema::Wiki::VERSION = '0.15';
+  $Silki::Schema::Wiki::VERSION = '0.16';
 }
 
 use strict;
@@ -1082,13 +1082,18 @@ sub _BuildActiveUsersSelect {
     my $page_t = $Schema->table('Page');
     my $page_revision_t = $Schema->table('PageRevision');
 
-    my $order_by = Fey::Literal::Term->new(
+    my $username_or_display_name = Fey::Literal::Term->new(
         q{CASE WHEN display_name = '' THEN username ELSE display_name END});
 
+    my $max = Fey::Literal::Function->new(
+        'MAX',
+        $page_revision_t->column('creation_datetime')
+    );
+
     my $users_select = Silki::Schema->SQLFactoryClass()->new_select();
 
     $users_select
-        ->select( $user_t, $order_by )
+        ->select( $user_t, $username_or_display_name, $max )
         ->distinct()
         ->from( $user_t, $page_revision_t )
         ->from( $page_revision_t, $page_t )
@@ -1101,7 +1106,8 @@ sub _BuildActiveUsersSelect {
                 DateTime->today()->subtract( months => 1 )
             )
         )
-        ->order_by($order_by);
+        ->group_by( $user_t->columns(), $username_or_display_name )
+        ->order_by( $max, 'DESC', $username_or_display_name, );
 
     return $users_select;
 }
@@ -1120,11 +1126,12 @@ sub _BuildActiveUsersSelect {
 #       "PageRevision"."comment",
 #       "PageRevision"."creation_datetime",
 #       ...,
-#       TS_RANK("Page"."ts_text", "page") AS "rank"
+#       TS_RANK("PageSearchableText"."ts_text", "page") AS "rank"
 #     FROM
 #      "Page" JOIN "PageRevision" ON ("PageRevision"."page_id" = "Page"."page_id")
+#             JOIN "PageSearchableText" ON ("PageSearchableText"."page_id" = "Page"."page_id")
 #     WHERE
-#      "Page"."ts_text" @@ to_tsquery(?)
+#      "PageSearchableText"."ts_text" @@ to_tsquery(?)
 #       AND
 #      "Page"."wiki_id" = ?
 #       AND
@@ -1766,7 +1773,7 @@ Silki::Schema::Wiki - Represents a wiki
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 AUTHOR
 
